@@ -1,8 +1,8 @@
-# This code is part of Perl distribution Mail-Box-Parser-C version 3.013.
-# The POD got stripped from this file by OODoc version 3.05.
+# This code is part of Perl distribution Mail-Box-Parser-C version 3.014.
+# The POD got stripped from this file by OODoc version 3.06.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2002-2025 by Mark Overmeer.
+# This software is copyright (c) 2002-2026 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -12,12 +12,12 @@
 #XXX WARNING: large overlap with Mail::Box::Parser:Perl; you may need to change both!
 
 package Mail::Box::Parser::C;{
-our $VERSION = '3.013';
+our $VERSION = '3.014';
 }
 
 use base qw/Mail::Box::Parser DynaLoader/;
 
-our $VERSION = '3.013';
+our $VERSION = '3.014';
 
 use strict;
 use warnings;
@@ -28,7 +28,7 @@ use Mail::Message::Field ();
 
 bootstrap Mail::Box::Parser::C $VERSION;
 
-## Defined in the library
+## Defined in the XS library
 sub open_filename($$$);
 sub open_filehandle($$$);
 sub get_filehandle($);
@@ -54,25 +54,26 @@ sub body_delayed($$$);
 
 sub init(@)
 {	my ($self, $args) = @_;
-	$self->SUPER::init($args) or return;
+	$self->SUPER::init($args);
 
-	$self->{MBPC_mode}     = $args->{mode} || 'r';
-	$self->{MBPC_filename} = $args->{filename} || ref $args->{file}
-		or $self->log(ERROR => "Filename or handle required to create a parser."), return;
+	$self->{MBPC_file}     = my $fh = $args->{file};
+	$self->{MBPC_mode}     = $args->{mode}     || 'r';
+	$self->{MBPC_filename} = $args->{filename} || ref $fh
+		or error __x"filename or handle required to create a parser.";
 
-	$self->start(file => $args->{file});
+	$self->start;
 	$self;
 }
 
 #--------------------
 
-sub boxnr() { $_[0]->{MBPC_boxnr} }
-
-
 sub filename() { $_[0]->{MBPC_filename} }
 sub openMode() { $_[0]->{MBPC_mode} }
 sub file()     { $_[0]->{MBPC_file} }
 
+
+sub boxnr()    { $_[0]->{MBPC_boxnr} }
+
 #--------------------
 
 sub start(@)
@@ -160,9 +161,11 @@ sub openFile(%)
 
 	my $boxnr;
 	my $name = $args{filename} || $self->filename;
+	my $mode = $args{mode}     || $self->openMode;
+	my $fh   = $args{file}     || $self->file;
 
 	if(my $file = $args{file})
-	{	$boxnr   = open_filehandle($file, $name // "$file", $log{trace});
+	{	$boxnr   = open_filehandle($fh, $name // "$fh", $log{trace});
 	}
 	else
 	{	my $mode = $args{mode} || $self->openMode || 'r';
